%FUNCTIONAL USAGE NOTE
%plot (function - Y Axis, timeframe - X Axis, color)

%GENERATION OF THE CURVES AND THE CAMSHAFT
dt = 0.001;              %Time increment

%GEOMETRICAL PARAMETERS
h1 = 1.5;               %minimum radius of cam
h2 = 4;                 %maximum radius of cam
dv = h2 - h1;           %diff between min and max positions of the camshaft, maximum movement
ratio = 4;              %1-4, 'E' in I:E (Inspiratory:Expiratory) ratio, assume I=1 always


on=1;
%LINEAR BREATHING CURVE
%------------------------------------------------------------
%------------------------------------------------------------
%IE: PLOT of the normalized breathing cycle
theta = 0:dt:1;         %time coordinate during one cycle, <start at 0>:<increment>:<length at 1>
y = [];
for i = 1:numel(theta);
    if theta(i) <= (1/(ratio+1))
        y(i) = (ratio+1)*theta(i);
    elseif theta(i) > (1/(ratio+1))
        y(i) = ((ratio+1)/ratio) - ((ratio+1)/ratio)*theta(i);
    end;
end;
if on
    fnorm = figure('Name', strcat('Breath: 1:', int2str(ratio)), 'Units', 'inches', 'NumberTitle', 'off');
    hold on
    plot(theta, y, '-b')
    hold off
end;


on=1;
%------------------------------------------------------------
%------------------------------------------------------------
%PLOT of a 1-cycle camshaft
theta2 = 0:dt:2*pi;     %time coordinate during one cycle, <start at 0>:<increment>:<length at 2pi>
rhocam = [];
for i = 1:numel(theta2);
    j = ceil(i / (2*pi));
    rhocam(i) = h1 + dv*y(j);
end;
if on
    fcam = figure('Name', strcat('Cam: 1:', int2str(ratio))', 'Units', 'inches', 'NumberTitle', 'off');
    polar(theta2, rhocam, '-b')
end;